@@ -10,8 +10,13 @@ PATH = str(Path(__file__).parent.absolute()) + "/"
 LOG_FOLDER = "{}/logs/".format(PATH)
 LOG_LEVEL = logging.INFO
 
+#Folder for the jobs
+PDF_REPORT_JOB_FOLDER = os.environ.get("PDF_REPORT_JOB_FOLDER")
+
 # Configuration for Superset-API
-SUPERSET_URL = os.environ.get("SUPERSET_URL")
+HOST_PROTOCOL = os.environ.get("HOST_PROTOCOL")
+HOST_NAME = os.environ.get("HOST_NAME")
+SUPERSET_URL = "{}://{}".format(HOST_PROTOCOL, HOST_NAME)
 SUPERSET_API_USER = os.environ.get("SUPERSET_API_USER")
 SUPERSET_API_PASSWORD = os.environ.get("SUPERSET_API_PASSWORD")
 
